@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # imports (over here to prevent circular).
-from dev0s.classes.system import disks, env, service, system, browser
+from dev0s.classes.system import disks, env, service, system, browser, metrics, cleanup
 
 # the system module class.
 class System():
@@ -23,4 +23,10 @@ class System():
 	Group = system.Group
 
 	# browser.
-	Browser = browser.Browser
\ No newline at end of file
+	Browser = browser.Browser
+
+	# metrics.
+	metrics = metrics.Metrics()
+
+	# cleanup.
+	cleanup = cleanup.CleanUp()
